@@ -280,13 +280,14 @@ void SetParamLines(int *action,int *nLines, double *linesimufactor,
     tbm->lines=*nLines;
     if (*linesimufactor < 0.0 || *linesimustep < 0.0) 
 	PRINTF("Both %s.linesimustep and %s.linesimufactor and must be non-negative\n", name, name); 
-    tbm->linesimufactor=*linesimufactor<0 ? 0 : *linesimufactor;
-    tbm->linesimustep=*linesimustep<0 ? 0 : *linesimustep;    
+    tbm->linesimufactor=*linesimufactor < 0.0 ? 0.0 : *linesimufactor;
+    tbm->linesimustep=*linesimustep < 0.0 ? 0.0 : *linesimustep;    
     if (*linesimufactor!=0.0 && *linesimustep!=0.0 && GENERAL_PRINTLEVEL>0 &&
 	(*linesimustep_o != *linesimustep || 
 	 *linesimufactor_o != *linesimufactor)) {
       if (GENERAL_PRINTLEVEL>0) 
-	  PRINTF("%s.linesimufactor is ignored!\n", name); 
+	PRINTF("%s.linesimufactor is ignored if %s.linesimustep is positive!\n", 
+	       name, name); 
       *linesimustep_o = *linesimustep;
       *linesimufactor_o = *linesimufactor;
       // else, i.e. both are zero, the old values are kept!
@@ -611,15 +612,20 @@ int init_turningbands(key_type *key, SimulationType method, int m)
 				s->simugrid, &(s->x))) != NOERROR)
       goto ErrorHandling;
  
-//  printf("TRANSF %d %d %d %d  %d %d\n", iloop, key->anisotropy, key->Time,
-//	   key->grid, totaltimespacedim, s->simugrid);
-//  printf("s->x %f %f %f\n\n", s->x[0], s->x[1] , s->x[2]);
-//  printf("aniso %f %f %f %f %f %f %f %f %f \n\n", 
-//	 s->aniso[0], s->aniso[1], s->aniso[2], s->aniso[3],
-//	 s->aniso[4], s->aniso[5], s->aniso[6], s->aniso[7],
-//	 s->aniso[8]);
-//  printf("first %f %f %f %f \n\n", 
-//	 first->aniso[0], first->aniso[1], first->aniso[2], first->aniso[3]);
+/*
+  printf("TRANSF %d %d %d %d  %d %d\n", iloop, key->anisotropy, key->Time,
+	   key->grid, totaltimespacedim, s->simugrid);
+  printf("s->x %f %f %f\n\n", s->x[0], s->x[1] , s->x[2]);
+  printf("aniso %f %f %f %f %f %f %f %f %f \n\n", 
+	 s->aniso[0], s->aniso[1], s->aniso[2], s->aniso[3],
+	 s->aniso[4], s->aniso[5], s->aniso[6], s->aniso[7],
+	 s->aniso[8]);
+  printf("first %f %f %f %f \n\n", 
+	 first->aniso[0], first->aniso[1], first->aniso[2], first->aniso[3]);
+  for (i=0; i<12*3; i++) printf("%f ", s->x[i]);
+  printf("\n");
+  // assert(false);
+  */
     
     GetCenterAndDiameter(key, s->simugrid, s->simuspatialdim,  
 			 totaltimespacedim, s->x, s->aniso,
